@@ -7,12 +7,12 @@ class InsightGenerator(metaclass=abc.ABCMeta):
     @classmethod
     def __subclasshook__(cls, subclass):
 
-        return (hasattr(subclass, 'execute') and
-                callable(subclass.execute) and
-                hasattr(subclass, 'write_to_table') and
-                callable(subclass.write_to_table) and
-                hasattr(subclass, 'provideEvidence') and
-                callable(subclass.provideEvidence) or
+        return (hasattr(subclass, 'define_query') and
+                callable(subclass.define_query) and
+                hasattr(subclass, 'transform') and
+                callable(subclass.transform) and
+                hasattr(subclass, 'provide_evidence') and
+                callable(subclass.provide_evidence) or
                 NotImplemented)
 
     @abc.abstractmethod
